@@ -7,6 +7,3 @@ Go to the documentation for wavinfo.WavInfoReader for more information.
 from .wave_reader import WavInfoReader
 from .riff_parser import WavInfoEOFError
 
-__version__ = '1.6.2'
-__author__ = 'Jamie Hardt <jamiehardt@gmail.com>'
-__license__ = "MIT"
